from setuptools import setup, find_packages

setup(
    name='mirageml',
    version='0.0.8',
    author='Aman Kishore',
    author_email='aman@mirageml.com',
    description='A basic pip package with basic commands like help and hello world',
    packages=find_packages(),
    install_requires=[
        # List your package's dependencies here
    ],
    entry_points={
        'console_scripts': [
            'mirageml=mirageml_pip.__main__:main'
        ]
    }
)


import argparse
from .commands import hello, help

def main():
    parser = argparse.ArgumentParser(description="mypackage CLI")
    subparsers = parser.add_subparsers(dest="command")

    hello_parser = subparsers.add_parser('hello', help='prints hello world')

    args = parser.parse_args()

    if args.command == "hello":
        hello()
    else:
        parser.print_help()

if __name__ == "__main__":
    main()
